Style guide for pymirc
======================

* no tabs in source code (use spaces)
* use 2 or 4 spaces for indentation
* use numpy style for docstrings  https://sphinxcontrib-napoleon.readthedocs.io/en/latest/
